==> scraping-1.1.24-sources.jar: com/tenqube/visual_scraper/model/view/OrderInfo.java <==
package com.tenqube.visual_scraper.model.view;

import java.util.Date;

public class OrderInfo {

    private final int _id;

    private final int mId;

    private final int uId;

    private final String title;

    private final Date orderDate;

    private final Date orderHms;

    private final String orderOption;

    private final int quantity;

    private final double price;

    private final String currency;

    private final String orderNum;

    private final String orderState;

    private final String imgUrl;

    private final String detailOrderLink;

    private final String detailProductLink;

    public OrderInfo(int _id, int mId, int uId, String title, Date orderDate, Date orderHms, String orderOption, int quantity, double price, String currency, String orderNum, String orderState, String imgUrl, String detailOrderLink, String detailProductLink) {
        this._id = _id;
        this.mId = mId;
        this.uId = uId;
        this.title = title;
        this.orderDate = orderDate;
        this.orderHms = orderHms;
        this.orderOption = orderOption;
        this.quantity = quantity;
        this.price = price;
        this.currency = currency;
        this.orderNum = orderNum;
        this.orderState = orderState;
        this.imgUrl = imgUrl;
        this.detailOrderLink = detailOrderLink;
        this.detailProductLink = detailProductLink;
    }

    public int get_id() {
        return _id;
    }

    public int getmId() {
        return mId;
    }

    public int getuId() {
        return uId;
    }

    public String getTitle() {
        return title;
    }

    public Date getOrderDate() {
        return orderDate;
    }

    public Date getOrderHms() {
        return orderHms;
    }

    public String getOrderOption() {
        return orderOption;
    }

    public int getQuantity() {
        return quantity;
    }

    public double getPrice() {
        return price;
    }

    public String getCurrency() {
        return currency;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public String getOrderState() {
        return orderState;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public String getDetailOrderLink() {
        return detailOrderLink;
    }

    public String getDetailProductLink() {
        return detailProductLink;
    }

    @Override
    public String toString() {
        return "OrderInfo{" +
                "_id=" + _id +
                ", mId=" + mId +
                ", uId=" + uId +
                ", title='" + title + '\'' +
                ", orderDate=" + orderDate +
                ", orderHms=" + orderHms +
                ", orderOption='" + orderOption + '\'' +
                ", quantity=" + quantity +
                ", price=" + price +
                ", currency='" + currency + '\'' +
                ", orderNum='" + orderNum + '\'' +
                ", orderState='" + orderState + '\'' +
                ", imgUrl='" + imgUrl + '\'' +
                ", detailOrderLink='" + detailOrderLink + '\'' +
                ", detailProductLink='" + detailProductLink + '\'' +
                '}';
    }
}

==> scraping-1.2.0-sources.jar: com/tenqube/visual_scraper/model/view/OrderInfo.java <==
package com.tenqube.visual_scraper.model.view;

import java.util.Date;

public class OrderInfo {

    private final int _id;

    private final int mId;

    private final int uId;

    private final String title;

    private final Date orderDate;

    private final Date orderHms;

    private final String orderOption;

    private final int quantity;

    private final double price;

    private final String currency;

    private final String orderNum;

    private final String orderState;

    private final String imgUrl;

    private final String detailOrderLink;

    private final String detailProductLink;

    private final int mallIconResId;

    private final String mallIconUrl;

    public OrderInfo(int _id,
                     int mId,
                     int uId,
                     String title,
                     Date orderDate,
                     Date orderHms,
                     String orderOption,
                     int quantity,
                     double price,
                     String currency,
                     String orderNum,
                     String orderState,
                     String imgUrl,
                     String detailOrderLink,
                     String detailProductLink,
                     int mallIconResId,
                     String mallIconUrl) {
        this._id = _id;
        this.mId = mId;
        this.uId = uId;
        this.title = title;
        this.orderDate = orderDate;
        this.orderHms = orderHms;
        this.orderOption = orderOption;
        this.quantity = quantity;
        this.price = price;
        this.currency = currency;
        this.orderNum = orderNum;
        this.orderState = orderState;
        this.imgUrl = imgUrl;
        this.detailOrderLink = detailOrderLink;
        this.detailProductLink = detailProductLink;
        this.mallIconResId = mallIconResId;
        this.mallIconUrl = mallIconUrl;
    }

    public int get_id() {
        return _id;
    }

    public int getmId() {
        return mId;
    }

    public int getuId() {
        return uId;
    }

    public String getTitle() {
        return title;
    }

    public Date getOrderDate() {
        return orderDate;
    }

    public Date getOrderHms() {
        return orderHms;
    }

    public String getOrderOption() {
        return orderOption;
    }

    public int getQuantity() {
        return quantity;
    }

    public double getPrice() {
        return price;
    }

    public String getCurrency() {
        return currency;
    }

    public String getOrderNum() {
        return orderNum;
    }

    public String getOrderState() {
        return orderState;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public String getDetailOrderLink() {
        return detailOrderLink;
    }

    public String getDetailProductLink() {
        return detailProductLink;
    }

    public int getMallIconResId() {
        return mallIconResId;
    }

    public String getMallIconUrl() {
        return mallIconUrl;
    }

    @Override
    public String toString() {
        return "OrderInfo{" +
                "_id=" + _id +
                ", mId=" + mId +
                ", uId=" + uId +
                ", title='" + title + '\'' +
                ", orderDate=" + orderDate +
                ", orderHms=" + orderHms +
                ", orderOption='" + orderOption + '\'' +
                ", quantity=" + quantity +
                ", price=" + price +
                ", currency='" + currency + '\'' +
                ", orderNum='" + orderNum + '\'' +
                ", orderState='" + orderState + '\'' +
                ", imgUrl='" + imgUrl + '\'' +
                ", detailOrderLink='" + detailOrderLink + '\'' +
                ", detailProductLink='" + detailProductLink + '\'' +
                '}';
    }
}
